# -------------------------------------------------------------------------------------------
#
# How to build for normal kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-8.1.15.el5' gspcav1.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-8.1.15.el5' gspcav1.spec
#
# How to build for normal kernel and XEN kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-8.1.15.el5' --define 'buildxen 1' gspcav1.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-8.1.15.el5' --define 'buildxen 1' gspcav1.spec
#
# How to build for normal kernel and PAE kernel
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-8.1.15.el5' --define 'buildPAE 1' gspcav1.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-8.1.15.el5' --define 'buildPAE 1' gspcav1.spec
#
# How to build for all kernel (normal, xen, PAE)
#
#  rpmbuild -ba --target i686   --define 'kernel 2.6.18-8.1.15.el5' --define 'buildall 1' gspcav1.spec
#  rpmbuild -ba --target x86_64 --define 'kernel 2.6.18-8.1.15.el5' --define 'buildall 1' gspcav1.spec
#
#
# How to build for the running kernel:
#
#  rpmbuild -ba --target i686   gspcav1.spec
#  rpmbuild -ba --target x86_64 gspcav1.spec
#
# -------------------------------------------------------------------------------------------

%{!?buildxen:%define buildxen 0}
%{!?buildPAE:%define buildPAE 0}

%{?buildall:%define buildxen 1}
%{?buildall:%define buildPAE 1}

%ifarch x86_64
%define buildPAE 0
%endif

%{?!kernel:%define kernel %(rpm -q kernel-devel | tail -1 | sed -e 's|kernel-devel-||')}

%define kversion %(echo "%{kernel}" | sed -e 's|-.*||')
%define krelease %(echo "%{kernel}" | sed -e 's|.*-||')

%define kernel_src_path %{_usrsrc}/kernels/%{kernel}-%{_target_cpu}
%define kernel_xen_src_path %{_usrsrc}/kernels/%{kernel}-xen-%{_target_cpu}
%define kernel_PAE_src_path %{_usrsrc}/kernels/%{kernel}-PAE-%{_target_cpu}

%define kernel_moduledir /lib/modules/%{kernel}
%define kernel_xen_moduledir /lib/modules/%{kernel}xen
%define kernel_PAE_moduledir /lib/modules/%{kernel}PAE

%define pkg_name gspcav1
%define kmdl_name kernel-module-%{pkg_name}-%{kernel}

# -------------------------------------------------------------------------------------------

Summary: 	A video for linux driver for webcams
Name: 		%{pkg_name}
Version: 	01.00.20
%define date 	20071224
Release: 	5.sl5
Epoch: 		0
Packager: 	Urs Beyerle <urs.beyerle@psi.ch>
License: 	GPL
Group: 		System Environment/Kernel
Source0: 	http://mxhaard.free.fr/spca50x/Download/gspcav1-%{date}.tar.gz
BuildRoot: 	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
Requires:       kernel-module-%{pkg_name} >= %{version}-%{release}
BuildRequires: 	kernel-devel = %{kernel}
%if %{buildxen}
BuildRequires: 	kernel-xen-devel = %{kernel}
%endif
%if %{buildPAE}
BuildRequires: 	kernel-PAE-devel = %{kernel}
%endif

%description
gspcav1 "Generic Software Package for Camera Adaptator"
replaces the spca5xx kernel module.
It is a video for linux (v4l) driver, providing 
support for webcams and digital cameras based on 
the spca5xx range of chips manufactured by SunPlus, Sonix,
Z-star, Vimicro, Conexant, Etoms, Transvision, Mars-Semi Pixart.

Kernel modules for %{name} are in kernel-module-%{pkg_name} rpms.

%package -n 	%{kmdl_name}
Summary:        Kernel modules for %{name}.
Group:          System Environment/Kernel
License:        GPL
Provides:       kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
# Requires:       %{pkg_name}

%description -n %{kmdl_name}
Kernel modules for %{name}.

gspcav1 "Generic Software Package for Camera Adaptator"
replaces the spca5xx kernel module.
It is a video for linux (v4l) driver, providing 
support for webcams and digital cameras based on 
the spca5xx range of chips manufactured by SunPlus, Sonix,
Z-star, Vimicro, Conexant, Etoms, Transvision, Mars-Semi Pixart.


%if %{buildxen}
%package -n 	%{kmdl_name}xen
Summary: 	Xen kernel modules for %{name}.
Group: 		System Environment/Kernel
License: 	GPL
Provides:	kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
# Requires:	%{pkg_name}

%description -n %{kmdl_name}xen
XEN kernel modules for %{name}.

gspcav1 "Generic Software Package for Camera Adaptator"
replaces the spca5xx kernel module.
It is a video for linux (v4l) driver, providing 
support for webcams and digital cameras based on 
the spca5xx range of chips manufactured by SunPlus, Sonix,
Z-star, Vimicro, Conexant, Etoms, Transvision, Mars-Semi Pixart.
%endif

%if %{buildPAE}
%package -n 	%{kmdl_name}PAE
Summary: 	PAE kernel modules for %{name}.
Group: 		System Environment/Kernel
License: 	GPL
Provides:	kernel-module-%{pkg_name} = %{epoch}:%{version}-%{release}
# Requires:	%{pkg_name}

%description -n %{kmdl_name}PAE
PAE kernel modules for %{name}.

gspcav1 "Generic Software Package for Camera Adaptator"
replaces the spca5xx kernel module.
It is a video for linux (v4l) driver, providing 
support for webcams and digital cameras based on 
the spca5xx range of chips manufactured by SunPlus, Sonix,
Z-star, Vimicro, Conexant, Etoms, Transvision, Mars-Semi Pixart.
%endif

%prep
%setup -q -n %{name}-%{date}
grep -rl '#include <linux/config.h>' . | \
     xargs perl -pi -e's,#include <linux/config.h>,/* #include <linux/config.h> */,'
# disable driver debug messages 
sed "s|DEFINES   += -DGSPCA_ENABLE_DEBUG|#DEFINES   += -DGSPCA_ENABLE_DEBUG|" -i Makefile

%build
echo -e "\nDriver version: %{version}\nKernel version: %{kernel}\n"

%define 	kernel_module_dir	kernel/drivers/usb/media

### kernel
make clean
make -C %{kernel_src_path} SUBDIRS=`pwd` modules
INST_MODLIB=${RPM_BUILD_ROOT}/lib/modules/%{kernel}/%{kernel_module_dir}
mkdir -p ${INST_MODLIB}
cp *.ko ${INST_MODLIB}/


### XEN kernel
%if %{buildxen}

make clean
make -C %{kernel_xen_src_path} SUBDIRS=`pwd` modules
INST_MODLIB=${RPM_BUILD_ROOT}/lib/modules/%{kernel}xen/%{kernel_module_dir}
mkdir -p ${INST_MODLIB}
cp *.ko ${INST_MODLIB}/

%endif


### PAE kernel
%if %{buildPAE}

make clean
make -C %{kernel_PAE_src_path} SUBDIRS=`pwd` modules
INST_MODLIB=${RPM_BUILD_ROOT}/lib/modules/%{kernel}PAE/%{kernel_module_dir}
mkdir -p ${INST_MODLIB}
cp *.ko ${INST_MODLIB}/

%endif


%install
echo

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%postun -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :	

%post -n %{kmdl_name}
depmod -a %{kernel} >/dev/null 2>&1 || :

%if %{buildxen}
%postun -n %{kmdl_name}xen
depmod -a %{kernel}xen >/dev/null 2>&1 || :

%post -n %{kmdl_name}xen
depmod -a %{kernel}xen >/dev/null 2>&1 || :
%endif

%if %{buildPAE}
%postun -n %{kmdl_name}PAE
depmod -a %{kernel}PAE >/dev/null 2>&1 || :

%post -n %{kmdl_name}PAE
depmod -a %{kernel}PAE >/dev/null 2>&1 || :
%endif


%files 
%defattr(-,root,root,-)
%doc changelog

%files -n %{kmdl_name}
%defattr(644,root,root,-)
/lib/modules/%{kernel}/%{kernel_module_dir}/gspca.*o

%if %{buildxen}
%files -n %{kmdl_name}xen
%defattr(644,root,root,-)
/lib/modules/%{kernel}xen/%{kernel_module_dir}/gspca.*o
%endif

%if %{buildPAE}
%files -n %{kmdl_name}PAE
%defattr(644,root,root,-)
/lib/modules/%{kernel}PAE/%{kernel_module_dir}/gspca.*o
%endif


%changelog
* Thu May 15 2008 Urs Beyerle <urs.beyerle@psi.ch> - 1.00.20-1
- update to Version 01.00.20, date 2007-12-24

* Thu Nov 08 2007 Urs Beyerle <urs.beyerle@psi.ch> - 1.00.18-1
- initial build for SL5
